<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
    <context>
        <name>desktop</name>
        <message>
            <location filename="Desktop Entry]Comment" line="0"/>
            <source>Calendar is a date tool.</source>
            <translation>Εφαρμογή Ημερολογίου </translation>
        </message>
        <message>
            <location filename="Desktop Entry]Name" line="0"/>
            <source>Deepin Calendar</source>
            <translation>Ημερολόγιο Deepin</translation>
        </message>
    </context>
</TS>